==> style-o-matic-1.1.3.tgz: package/es/components/Form/Form.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getCorePropTypes, getCorePropDefaults, getValidProps, ROLE } from "../../lib";
import Input from "../Input/Input.js";
import Radio from "../Radio/Radio.js";
import Select from "../Select/Select.js";
import Textarea from "../Textarea/Textarea.js";
import FormRow from "./FormRow.js";
import "./Form.css";

var Form = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Form, _CoreComponent);

  function Form() {
    var _temp, _this, _ret;

    _classCallCheck(this, Form);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.getFieldValue = function (fieldKey) {
      var value = null;
      for (var i = 0; i < _this.rows.length; i += 1) {
        var row = _this.rows[i];
        var fieldValue = row.getFieldValue(fieldKey);
        if (fieldValue) {
          value = fieldValue;
        }
      }
      if (!value) {
        _this.fields.map(function (field) {
          if (field.key === fieldKey) {
            value = field.element.getValue();
          }
          return null;
        });
      }
      return value;
    }, _this.getFormData = function () {
      var formData = {};
      for (var i = 0; i < _this.rows.length; i += 1) {
        var row = _this.rows[i];
        var rowFields = row.getAllFieldValues();
        for (var x = 0; x < rowFields.length; x += 1) {
          var field = rowFields[x];
          formData[field.key] = field.value;
        }
      }
      _this.fields.map(function (field) {
        formData[field.key] = field.element.getValue();
        return null;
      });
      return formData;
    }, _this.rows = [], _this.fields = {}, _this.handleForcedUpdate = function () {
      if (_this.node) {
        _this.forceUpdate();
      }
    }, _this.handleOnInvalid = function (e) {
      // console.log(e);
    }, _this.handleOnSubmit = function (e) {
      if (_this.props.onSubmit) {
        var formData = _this.getFormData();
        _this.props.onSubmit(e, formData);
      }
    }, _this.renderRow = function (child, props) {
      var role = child.props.uirole || ROLE.ROW;
      var ref = function ref(c) {
        _this.rows.push(c);
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this.childPrefix(role)
      }));
    }, _this.renderInput = function (child, props) {
      var role = child.props.uirole || ROLE.INPUT;
      var key = child.props.name || child.props.id;
      var ref = function ref(c) {
        _this.fields.push({ key: key, value: c });
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this.childPrefix(role)
      }));
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Form.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    this.rows = [];
    this.fields = [];

    delete props.onSubmit;

    return React.createElement(
      Component,
      _extends({}, props, { ref: this.onSetRef, onSubmit: this.handleOnSubmit }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.ROW:
              return _this2.renderRow(child, inherited);
            case ROLE.INPUT:
              return _this2.renderInput(child, inherited);
            default:
              return child;
          }
        }
        return child;
      })
    );
  };

  return Form;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "form",
  uirole: ROLE.FORM
}), _class.Row = FormRow, _class.Input = Input, _class.Radio = Radio, _class.Select = Select, _class.Textarea = Textarea, _temp2);


export default Form;

==> style-o-matic-1.1.5.tgz: package/es/components/Form/Form.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, setCorePropTypes, setCorePropDefaults, getValidProps, ROLE } from "../../lib";
import Input from "../Input/Input.js";
import Radio from "../Radio/Radio.js";
import Select from "../Select/Select.js";
import Textarea from "../Textarea/Textarea.js";
import FormRow from "./FormRow.js";
import "./Form.css";

var Form = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Form, _CoreComponent);

  function Form() {
    var _temp, _this, _ret;

    _classCallCheck(this, Form);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.getFieldValue = function (fieldKey) {
      var value = null;
      for (var i = 0; i < _this.rows.length; i += 1) {
        var row = _this.rows[i];
        var fieldValue = row.getFieldValue(fieldKey);
        if (fieldValue) {
          value = fieldValue;
        }
      }
      if (!value) {
        _this.fields.map(function (field) {
          if (field.key === fieldKey) {
            value = field.element.getValue();
          }
          return null;
        });
      }
      return value;
    }, _this.getFormData = function () {
      var formData = {};
      for (var i = 0; i < _this.rows.length; i += 1) {
        var row = _this.rows[i];
        var rowFields = row.getAllFieldValues();
        for (var x = 0; x < rowFields.length; x += 1) {
          var field = rowFields[x];
          formData[field.key] = field.value;
        }
      }
      _this.fields.map(function (field) {
        formData[field.key] = field.element.getValue();
        return null;
      });
      return formData;
    }, _this.rows = [], _this.fields = [], _this.handleForcedUpdate = function () {
      if (_this.node) {
        _this.forceUpdate();
      }
    }, _this.handleOnInvalid = function (e) {
      // console.log(e);
    }, _this.handleOnSubmit = function (e) {
      if (_this.props.onSubmit) {
        var formData = _this.getFormData();
        _this.props.onSubmit(e, formData);
      }
    }, _this.renderRow = function (child, props) {
      var role = child.props.uirole || ROLE.ROW;
      var ref = function ref(c) {
        if (c) {
          _this.rows.push(c);
        }
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this.childPrefix(role)
      }));
    }, _this.renderInput = function (child, props) {
      var role = child.props.uirole || ROLE.INPUT;
      var key = child.props.name || child.props.id;
      var ref = function ref(c) {
        if (c) {
          _this.fields.push({ key: key, element: c });
        }
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this.childPrefix(role)
      }));
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Form.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    this.rows = [];
    this.fields = [];

    delete props.onSubmit;

    return React.createElement(
      Component,
      _extends({}, props, { ref: this.onSetRef, onSubmit: this.handleOnSubmit }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.ROW:
              return _this2.renderRow(child, inherited);
            case ROLE.INPUT:
              return _this2.renderInput(child, inherited);
            case ROLE.DATEPICKER:
              return _this2.renderInput(child, inherited);
            default:
              return child;
          }
        }
        return child;
      })
    );
  };

  return Form;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "form",
  uirole: ROLE.FORM
}), _class.Row = FormRow, _class.Input = Input, _class.Radio = Radio, _class.Select = Select, _class.Textarea = Textarea, _temp2);


export default Form;
